Crate odem_rs_util

Crate odem_rs_util 

A library for ODEM-rs simulation-specific utility structures intended to provide quality-of-life improvements to modelers.

This library includes modules for managing pools of active objects, initializing independent random number streams, deriving statistics from measurements, and constructor functions for physical quantities. It is specifically designed for use in ODEM-rs simulation models.

Modules

arrivalsalloc
Module containing an experimental (unstable) extension trait for simulation contexts to facilitate the specification of an asynchronous generator for active objects.
error
A module for util-specific error types.
pool
This module defines an arena allocator for Active simulation objects that performs automatic garbage collection on terminated and unreferenced instances.
randomrand
Contains facilities to ease the creation, distribution and use of random number generators based on the rand-crate.
random_variable
This module contains support for random variables which are useful for aggregating statistical data of measurements taken during a simulation run.
siuom
Provides SI unit support and statistical compatibility for ODEM-rs.