pub enum Error {
Causality,
NegativeWeight,
InsufficientSpace,
}Expand description
Enumeration of errors for the functions and structures contained in this module of the simulation library.
Variants
Causality
Signals an attempt to tabulate a value at a time point that is in the past of the previous tabulation.
NegativeWeight
Signals an attempt to tabulate a value with negative weight.
InsufficientSpace
Signals that the storage space of a pool has been exhaused.