Pool

Struct Pool 

pub struct Pool<A, S: ?Sized = dyn Storage<Slot = Gc<A>>, F = ()> { /* private fields */ }
An arena allocator for Active simulation objects that performs automatic garbage collection on terminated and unreferenced instances.

This pool manages a Storage backend and a reclaim list of memory slots that are ready to be reused.

Safety Notes

Rearranging the fields here can lead to undefined behavior upon dropping of the pool. Specifically, dropping storage before reclaim will invalidate the slots contained in reclaim, leading to undefined behavior when reclaim is dropped later.

Implementations

Source

impl<A> Pool<A>

pub fn new<S>(storage: S) -> Pool<A, S>

Creates a new pool given a backing store.

pub fn fixed<const N: usize>() -> Pool<A, Array<Gc<A>, N>>

Creates a pool with a fixed-size backing store.

This pool is suitable for no_std + no_alloc environments. It will panic if an allocation is attempted when the pool is full.

pub fn dynamic() -> Pool<A, Arena<Gc<A>>>

Available on crate feature alloc only.

Creates a pool with a dynamically growing backing store.

pub fn with_capacity(n: usize) -> Pool<A, Arena<Gc<A>>>

Available on crate feature alloc only.

Creates a dynamically growing pool with a specified initial capacity.

Source

impl<A, S: Storage<Slot = Gc<A>>> Pool<A, S>

pub fn with<'p, B, F>(self, cons: F) -> Pool<A, S, F>
where F: Fn(B) -> Lease<'p, A>, A: 'p,

Sets a new constructor function for the pool.

Source

impl<A, S: ?Sized + Storage<Slot = Gc<A>>, F> Pool<A, S, F>

pub fn try_alloc<'a, 'p, B>( self: &'a Pin<&mut Self>, value: B, ) -> Result<Pin<&'a mut Lease<'a, Gc<A>>>, InsufficientSpace<B>>
where F: Cons<B, Lease<'p, A>>, A: 'p,

Attempts to allocate a new, Active object.

This method first tries to recycle a slot from the reclaim list. If the list is empty, it requests a new slot from the backing store.

This function is panic-safe. If the constructor function cons panics, the slot (whether recycled or newly allocated) is safely returned to the reclaim list, preventing memory leaks.

Returns a Result containing the pinned, allocated object, or the original value if allocation fails (e.g., the backing store is full).

pub fn alloc<'a, 'p, B>( self: &'a Pin<&mut Self>, value: B, ) -> Pin<&'a mut Lease<'a, Gc<A>>>
where F: Cons<B, Lease<'p, A>>, A: 'p,

Allocates a new, Active object, panicking if allocation fails.

This is a convenience wrapper around try_alloc that panics on allocation failure. This is often acceptable in simulations where the pool size is expected to be sufficient.

pub fn len(&self) -> usize

Returns the total number of allocated slots.

pub fn is_empty(&self) -> bool

Returns true if no slots have been allocated.