Utilized

Struct Utilized 

pub struct Utilized<T, S = bool>(pub T, pub S);
Represents a time-weighted sample that can effectively be used to calculate the utilization rate of model elements by tabulating (time-index, state) pairs for every state change.

Tuple Fields

0: T

The time index.

1: S

The value.