pub struct Utilized<T, S = bool>(pub T, pub S);Expand description
Represents a time-weighted sample that can effectively be used to calculate the utilization rate of model elements by tabulating (time-index, state) pairs for every state change.
Tuple Fields
0: TThe time index.
1: SThe value.